#
# spec file for package pspp
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2008 Matj Cepl <mcepl@redhat.com>
# Copyright (c) 2008 D. Steuer <steuer@hsuhh.de>
# Copyright (c) 2018 <astieger@suse.com>
# Copyright (c) 2010-2024 <opensuse.lietuviu.kalba@gmail.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?mandriva_version}
%define _disable_ld_no_undefined 1
#Next line is needed for Mandriva build
%define _disable_ld_as_needed 1
%endif
Name:           pspp
Version:        2.0.1
Release:        2.1
Summary:        A program for statistical analysis of sampled data
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://www.gnu.org/software/pspp/
Source0:        https://ftp.gnu.org/pub/gnu/pspp/pspp-%{version}.tar.gz
Source1:        https://ftp.gnu.org/pub/gnu/pspp/pspp-%{version}.tar.gz.sig
Source2:        https://savannah.gnu.org/people/viewgpg.php?user_id=245#/%{name}.keyring

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?fedora} 
BuildRequires:  atlas
%endif
%if 0%{?suse_version}
BuildRequires:  fdupes
BuildRequires:  update-desktop-files
PreReq:         %install_info_prereq
%endif
%if 0%{?is_opensuse}
# Next package only for "make check", but "free-ttf-fonts" exist only in openSUSE, not in SUSE
BuildRequires:  free-ttf-fonts
%endif
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  cairo-devel
BuildRequires:  desktop-file-utils
BuildRequires:  gettext >= 0.20
BuildRequires:  gsl-devel >= 1.12
BuildRequires:  gtk3-devel >= 3.22
BuildRequires:  gtksourceview4-devel
BuildRequires:  libtool
BuildRequires:  libxml2-devel
BuildRequires:  m4
BuildRequires:  pango-devel
BuildRequires:  perl(Text::Diff)
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(appstream)
BuildRequires:  postgresql-devel
BuildRequires:  python3-devel >= 3.4
BuildRequires:  readline-devel
BuildRequires:  spread-sheet-widget-devel >= 0.6
BuildRequires:  texinfo
BuildRequires:  zlib-devel
AutoReqProv:    Yes
Recommends:     %{name}-doc = %{version}

%description
PSPP is a program for statistical analysis of sampled data. It
is a free replacement for the proprietary program SPSS.

PSPP development is ongoing. It already supports a large subset of
SPSS's syntax. Its statistical procedure support is currently
limited, but growing. At your option, PSPP will produce statistical
reports in ASCII, PostScript, PDF, HTML, SVG, or OpenDocument formats.


%if 0%{?suse_version}
%lang_package
%else
%package lang
Summary:        Translations for package pspp
License:        GPL-3.0-or-later

%description lang
PSPP is a program for statistical analysis of sampled data. It
is a free replacement for the proprietary program SPSS.

This subpackage provides translations for PSPP.
%endif


%package devel
Summary:        Development files for PSPP, a statistical analysis program
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Requires:       cairo-devel
Requires:       glib2-devel
Requires:       glibc-devel
Requires:       gsl-devel
Requires:       harfbuzz-devel
Requires:       libxml2-devel
Requires:       pango-devel
Requires:       postgresql-devel
Requires:       zlib-devel
%if 0%{?suse_version} 
Requires:       xz-devel
%endif
Recommends:     %{name}-devel-doc = %{version}

%description devel
PSPP is a program for statistical analysis of sampled data. It
is a free replacement for the proprietary program SPSS.

This subpackage contains libraries and header files for developing
applications that want to build pspp plugins.


%package doc
Summary:        Manual for PSPP
License:        GPL-3.0-or-later
Requires:       %{name} = %{version}
BuildArch:      noarch

%description doc
PSPP is a program for statistical analysis of sampled data. It
is a free replacement for the proprietary program SPSS.

This subpackage contains documentation for PSPP.


%package devel-doc
Summary:        PSPP Developers Guide
License:        GPL-3.0-or-later
BuildArch:      noarch

%description devel-doc
PSPP is a program for statistical analysis of sampled data. It
is a free replacement for the proprietary program SPSS.

This subpackage contains development documentation for PSPP.


%prep
%setup -q -n pspp-%{version}

%build
export SUSE_ASNEEDED=0
export CFLAGS="%{optflags} -fgnu89-inline -fcommon"
%configure \
             --disable-relocatable --disable-static --disable-rpath \
             --without-libreadline-prefix

%if 0%{?suse_version} >= 1500 
%make_build
%else
make
%endif
make html

%install
%make_install
%if 0%{?suse_version}
%suse_update_desktop_file -r org.gnu.%{name} Education Math
%endif

# Use help in HTML
mv ./doc/pspp.html/ ./doc/pspp-dev.html/ %{buildroot}%{_datadir}/doc/pspp/
# don't need xml since we have html
rm -f %{buildroot}/%{_datadir}/doc/pspp/pspp.xml
# screenshots directory contains *.png, *.eps and *.grab, but only *.png is sufficient
rm -f %{buildroot}/%{_datadir}/doc/pspp/pspp.html/pspp-figures/*.{eps,grab}
# don't need pspp-figures directory because 
# * sps, html tables are already incorporated in html documentation
# * texi, txt, spv tables are redundant
# * png has very bad quality
[ -d %{buildroot}/%{_infodir}/pspp-figures ] && rm -fr %{buildroot}/%{_infodir}/pspp-figures
[ -d %{buildroot}%{_datadir}/doc/pspp/pspp.html/pspp-figures ] && rm -fr %{buildroot}%{_datadir}/doc/pspp/pspp.html/pspp-figures
# screenshots must not be in /usr/share/info, but in /usr/share/doc/pspp/pspp.html/
[ -d %{buildroot}/%{_infodir}/screenshots ] && mv %{buildroot}/%{_infodir}/screenshots/  %{buildroot}%{_datadir}/doc/pspp/pspp.html/
# don't own /usr/share/info/dir if it exist
[ -f %{buildroot}/%{_infodir}/dir ] && rm %{buildroot}/%{_infodir}/dir
# PSPP 2.0 no longer installs /usr/bin/pspp-dump-sav by default, thus its man is not needed
[ -f %{buildroot}/%{_mandir}/man1/pspp-dump-sav.1 ] && rm -f %{buildroot}/%{_mandir}/man1/pspp-dump-sav.1
# don't own /usr/share/info/dir if it exist
[ -f %{buildroot}/%{_infodir}/dir ] && rm %{buildroot}/%{_infodir}/dir

#Config for ld
mkdir -p %{buildroot}%{_sysconfdir}/ld.so.conf.d
cat >%{buildroot}%{_sysconfdir}/ld.so.conf.d/pspp.conf <<EOF
%{_libdir}/pspp
EOF

# AppData
mv $RPM_BUILD_ROOT/%{_datadir}/metainfo $RPM_BUILD_ROOT/%{_datadir}/appdata

%if 0%{?suse_version}
%fdupes -s %{buildroot}/%{_datadir}
%endif

# localization
%find_lang pspp

%check
export TESTSUITEFLAGS='-v -j128'
%make_build check || /bin/true
# just look into test results, don't need to package them
[ -f ./tests/testsuite.log ] && cat ./tests/testsuite.log

%post
/sbin/ldconfig
%install_info  --info-dir=%{_infodir}  %{_infodir}/pspp.info
%desktop_database_post

%preun
if [ $1 = 0 ] ; then
   %install_info_delete --info-dir=%{_infodir} %{_infodir}/pspp.info*
fi

%postun
/sbin/ldconfig
%desktop_database_postun

%files
%license COPYING
%doc README THANKS AUTHORS
%exclude %dir %{_datadir}/doc/pspp/
%config(noreplace) %{_sysconfdir}/ld.so.conf.d/pspp.conf
%{_bindir}/pspp
%{_bindir}/psppire
%{_bindir}/pspp-convert
%{_bindir}/pspp-output
%defattr(644,root,root,755)
%{_infodir}/pspp*info*
%dir %{_libdir}/pspp/
%{_libdir}/pspp/*.so
%{_datadir}/pspp
%exclude %dir %{_datadir}/pspp/tests
%exclude %{_datadir}/pspp/tests/testsuite.log
%{_datadir}/icons/hicolor/scalable/apps/org.gnu.pspp.svg
%{_datadir}/icons/hicolor/16x16/apps/org.gnu.pspp.png
%{_datadir}/icons/hicolor/16x16/mimetypes/application-x-spss-*.png
%{_datadir}/icons/hicolor/22x22/mimetypes/application-x-spss-*.png
%{_datadir}/icons/hicolor/24x24/mimetypes/application-x-spss-*.png
%{_datadir}/icons/hicolor/256x256/apps/org.gnu.pspp.png
%{_datadir}/icons/hicolor/256x256/mimetypes/application-x-spss-*.png
%{_datadir}/icons/hicolor/32x32/apps/org.gnu.pspp.png
%{_datadir}/icons/hicolor/32x32/mimetypes/application-x-spss-*.png
%{_datadir}/icons/hicolor/48x48/apps/org.gnu.pspp.png
%{_datadir}/icons/hicolor/48x48/mimetypes/application-x-spss-*.png
%{_datadir}/mime/packages/org.gnu.pspp.xml
%{_datadir}/applications/org.gnu.pspp.desktop
%{_datadir}/appdata/org.gnu.pspp.metainfo.xml
%if 0%{?mandriva_version} 
%doc %{_mandir}/man1/pspp.1.xz
%doc %{_mandir}/man1/psppire.1.xz
%doc %{_mandir}/man1/pspp-convert.1.xz
%doc %{_mandir}/man1/pspp-output.1.xz
%else
%doc %{_mandir}/man1/pspp.1.gz
%doc %{_mandir}/man1/psppire.1.gz
%doc %{_mandir}/man1/pspp-convert.1.gz
%doc %{_mandir}/man1/pspp-output.1.gz
%endif

%files lang -f %{name}.lang

%files devel
%dir %{_libdir}/pspp/
%{_libdir}/pspp/libpspp-core.la
%{_libdir}/pspp/libpspp.la

%files doc
%defattr(-, root, root)
%dir %{_datadir}/doc/pspp/
%dir %{_datadir}/doc/pspp/pspp.html/
%doc %{_datadir}/doc/pspp/pspp.html/*.html
%dir %{_datadir}/doc/pspp/pspp.html/screenshots/
%{_datadir}/doc/pspp/pspp.html/screenshots/*.png
%exclude %dir %{_datadir}/doc/pspp/pspp-dev.html/

%files devel-doc
%defattr(-, root, root)
%dir %{_datadir}/doc/pspp/pspp-dev.html/
%doc %{_datadir}/doc/pspp/pspp-dev.html/*.html


%changelog
* Sat Mar 15 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Drop pkgconfig(gtksourceview-3.0) BuildRequires: Not needed, nor
  used.
* Sat Mar 23 2024 opensuse.lietuviu.kalba@gmail.com
- Update to 2.0.1:
  * Translation updates.
  * CTABLES: Fix crash with single nesting level, no label, and moving labels.
  * AUTORECODE: Fix crash if scratch variables created before source variables.
  * CROSSTABS: Fix tabular output when columns or rows are empty.
  * psppire: Sort by name or label case-insensitively in dictionary view.
  * DO REPEAT: Accept duplicate names as substitution variables.
- Add BuildReuires perl(Text::Diff) for tests after compilation.
* Thu Mar 14 2024 opensuse.lietuviu.kalba@gmail.com
- Do not ship testsuite.log with pspp-devel package (boo#1221321)
* Mon Mar 11 2024 opensuse.lietuviu.kalba@gmail.com
- Improve documentation packaging.
- Add more suggested dependencies to -devel package.
* Mon Mar 11 2024 opensuse.lietuviu.kalba@gmail.com
- Update to 2.0.0:
  * The CTABLES command is now implemented.
  * FREQUENCIES now honors the LAYERED setting on SPLIT FILE.
  * AGGREGATE:
  - New aggregation functions CGT, CLT, CIN, and COUT.
  - Break variables are now optional.
  * ADD FILES, MATCH FILES, and UPDATE now allow string variables with
  the same name to have different widths.
  * CROSSTABS now calculates significance of Pearson and Spearman
  correlations in symmetric measures.
  * DISPLAY MACROS is now implemented.
  * SET SUMMARY is now implemented.
  * SHOW ENVIRONMENT is now implemented.
  * Removed the MODIFY VARS command, which is not in SPSS.
  * Building from a Git repository, which previously required GIMP, now
  requires rsvg-convert from librsvg2 instead.
  * The pspp-dump-sav program is no longer installed by default.
  * Improved the search options in the syntax editor.
  * Localisations for the ar (Arabic) and ta (Tamil) locales have been
  added.  Other translations have been updated.
  * Journaling is now enabled by default when PSPP or PSPPIRE is
  started interactively.  In PSPPIRE, use Edit|Options to override
  the default.
* Mon Mar 11 2024 opensuse.lietuviu.kalba@gmail.com
- Move screenshots and pspp-figures directories with images from
  /usr/share/info/ into /usr/share/doc/pspp/pspp.html/ because
  here HTML pages look for them.
* Sat Jul 22 2023 Klaus Kämpf <kkaempf@suse.com>
- Update to 1.6.2
  * Previously, numeric variables defaulted to "scale" measurement
    level.  Now, the default is "unknown", with a better guess chosen
    based on heuristics the first time the data is read.
  * Bug fixes.
- Update to 1.6.1
  * The SET command now supports LEADZERO for controlling output of a
    leading zero in F, COMMA, and DOT format.
  * Bug fixes and translation updates.
- Update to 1.6.0
  * In the Kruskal-Wallis test, a misleading result could occur
    if the lower bound specified by the user was in fact higher
    than the upper bound specified.  This has been fixed.
  * The DEFINE, MATRIX, MCONVERT, and MATRIX DATA commands are now
    implemented.
  * An error in the displayed signficance of oneway anova
    contrasts tests has been corrected.
  * Added Drag-N-Drop in output view.
  * The Explore GUI dialog supports the "Plots" subdialog. Boxplots,
    Q-Q Plots and Spreadlevel plots are now also available via the GUI.
  * The graphical user interface for importing spreadsheets has been
    improved.
    The new interface provides the user with a preview of the data to
    be imported and interactive methods to select the desired ranges.
  * The user manual, in its Info and HTML versions, now includes
    graphical output examples and screenshots.
  * New command SHOW SYSTEM to easily print system information useful
    in bug reports.
  * Output improvements:
  - New drivers for output to TeX source files and to PNG files.
  - Table output styles may now be set with the new option
  - -table-look and the new SET TLOOK command.
  - New driver option "trim" to remove empty space from PDF,
    PostScript, SVG, and PNG output files.
  - The PDF output driver now adds an outline to allow PDF viewers
    to display as a "table of contents" for the file.
  - The HTML output driver has a new option "bare".
  * New features in pspp-output:
  - New --table-look and --nth-commands options.
  - New get-table-look and convert-table-look commands.
* Thu Apr 28 2022 Dirk Müller <dmueller@suse.com>
- use https:// for Source urls
* Mon May 17 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Do not own filesystem owned directories like
  /usr/share/mime/packages and /usr/share/appdata.
* Sun Sep  6 2020 opensuse.lietuviu.kalba@gmail.com
- Update to PSPP 1.4.1:
  * Bug fixes.
  * Translation updates.
  * HTML output is now HTML5 instead of HTML4.0 Transitional.
  * The HOST command has been reimplemented.  It now supports TIMELIMIT.
- Split -lang package.
- Add documentation packages.
* Thu Aug 20 2020 opensuse.lietuviu.kalba@gmail.com
- Update to PSPP 1.4.0:
  * The file pspp-mode.el (the pspp-mode for Emacs) is no longer
    distributed with PSPP.  Instead, it can be installed directly
    in emacs and is available from
    https://elpa.gnu.org/packages/pspp-mode.html
  * The Find dialog box, when searching for numeric values, will
    match only to the precision of the variable's print format.
    This avoids behaviour which is suprising to some users.
  * PSPP now supports the SPSS viewer (.spv) format that SPSS 16 and
    later use to save the contents of its output editor:
  - PSPP and PSPPIRE can write output to .spv files.
  - The new utility pspp-output can convert .spv files to other
    formats.
  - The pspp-convert utility can now decrypt encrypted .spv files.
    The encrypted viewer file format is unacceptably insecure, so
    to discourage its use PSPP and PSPPIRE do not directly read or
    write this format.
  * A bug where the Data|Select Cases|Random Sample menu would
    generate invalid syntax has been fixed.
  * FREQUENCIES will emit a warning if one or more weight values are missing.
  * Plain text output is no longer divided into pages, since it is
    now rarely printed on paper.
  * pspp-convert improvements:
  - New "-a", "-l", "--password-list" options to search for an
    encrypted file's password.
  - New "--keep" and "--drop" options to output only selected
    variables.
  - New "--recode", "--no-var-name", "--labels", "--print-formats",
    "--decimal", "--delimiter", and "--qualifier" options to
    control CSV output.
  * Improvements to SAVE DATA COLLECTION support for MDD files.
  * Bug fix for CVE-2018-20230.
  * The /RENAME subcommand in SAVE TRANSLATE et al. has been extended
    to support the syntax also accepted by other software.
  * The EXAMINE command will now perform the Shapiro-Wilk test when
    one or more plots are requested.
  * The REGRESSION command now supports the /STATISTICS=TOL option which
    outputs tolerance and variance inflation factor metrics for the data.
  * The QUICK CLUSTER command now supports the /SAVE option which
    can be used to save the cases' cluster membership and/or their
    distance from the cluster centre to the active file.
  * The MEANS command has been re-implemented.
  * The GUI now has a sub-dialog for post-hoc tests of the oneway anova test.
  * GRAPH: Categorical barcharts displaying percentages now show
    the sub-category as a percentage of the primary category
    instead of the total.
  * The Syntax Window now has a Find function to perform simple text searching.
  * AUTORECODE:
    The PRINT subcommand is now implemented.
    Many bug fixes.
  * drop avoid_old_Texinfo_4.13.patch
  * drop CVE-2018-20230.patch
  *  drop CVE-2019-9211.patch
* Wed Jul 15 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- remove nondeterministic bits from testsuite.log
  to make package build reproducible
* Sat Jul  4 2020 opensuse.lietuviu.kalba@gmail.com
- Enable build for SLE 12SP5 and other distros than openSUSE.
- Add "Requires: xz-devel" for pspp-devel.
- Add tests/testsuite.log in pspp-devel.
* Mon Jun  8 2020 opensuse.lietuviu.kalba@gmail.com
- Add option -fcommon as a workaround for compilation with GCC10.
- Don't try delete /usr/share/info/dir which does not exist before
  compilation in openSUSE TW
* Fri Sep 13 2019 Matej Cepl <mcepl@suse.com>
- Switch on tests.
* Thu Feb 28 2019 opensuse.lietuviu.kalba@gmail.com
- Add upstream patch CVE-2019-9211.patch to fix CVE-2019-9211
  (boo#1127343).
* Wed Feb  6 2019 Jan Engelhardt <jengelh@inai.de>
- Remove excessive -n argument to %%build, and excessive %%defattr
  lines.
* Fri Jan  4 2019 Jan Engelhardt <jengelh@inai.de>
- Drop useless AutoReqProv: on.
* Thu Jan  3 2019 opensuse.lietuviu.kalba@gmail.com
- Add upstream patch CVE-2018-20230.patch to fix CVE-2018-20230
  (bnc#1120061).
- Add upstream patch avoid_old_Texinfo_4.13.patch to avoid
  compiling with old Texinfo 4.13.
* Sat Nov 10 2018 astieger@suse.com
- pspp 1.2.0:
  * New experimental command SAVE DATA COLLECTION to save MDD files
  * MTIME and YMDHMS variable formats now supported.
  * Spread sheet rendering now done via spread-sheet-widget
* Sat Nov 10 2018 astieger@suse.com
- add upstream signing key and verify source signature
* Mon Sep 11 2017 jengelh@inai.de
- Update boilerplate descriptions. Replace $RPM_ shell variables
  by macros. Unify mix of different CFLAGS.
* Tue Sep  5 2017 opensuse.lietuviu.kalba@gmail.com
- Removing ncurses dependency, because since 0.11.0 version,
  the ncurses library is no longer required or used.
* Tue Aug 29 2017 opensuse.lietuviu.kalba@gmail.com
- Update to 1.0.1 version:
  * Bug fixes, including fixes for CVE-2017-12958 (bnc#1054585),
    CVE-2017-12959 (bnc#1054588), CVE-2017-12960 (bnc#1054587), and
    CVE-2017-12961 (bnc#1054586).
  * Translation updates.
* Sun Aug 13 2017 opensuse.lietuviu.kalba@gmail.com
- Update to 0.11.0 version:
  * The REGRESSION command now has a /ORIGIN subcommand to perform
  regression through the origin.
  * The FACTOR command can now analyse matrix files prepared with MATRIX DATA.
  * The FACTOR command can now print the anti-image matrices.
  * The MATRIX DATA command has been added.
  * Some inappropriate properties in selection dialogs have been corrected.
  * A bug which could cause the HTML driver to go into a tight loop
  has been fixed.
  * An error in the FREQUENCIES procedure, where the word "Mean" was
  printed when "Variance" was appropriate has been fixed.
  * The ncurses library is no longer required or used.
  * A bug where the Mann-Whitney test would give misleading results
  if run on multiple variables and MISSING=ANALAYSIS was specified
  has been fixed.
  * Gtk+3.14.5 or later must now be used when building.
  * Graphical user interface changes:
  * There is a new menu: Edit|Options
  * The Non Parametric Statistics Menu has a new item: "K Independent Samples".
  * Dialog boxes can now be canceled using the <Escape> key.
  * The AUTORECODE command now accepts an optional / before INTO.
  * The short form of the VECTOR command can now create string variables.
  * Bug fixes, including fixes for CVE-2017-10791 and CVE-2017-10792.
- Drop pspp-0001-sys-file-reader-Avoid-null-dereference-skipping-bad-.patch:
  Fix for CVE-2017-10792 included in PSPP 0.11.0 version upstream.
- Drop pspp-0002-sys-file-reader-Fix-integer-overflows-in-parse_long_.patch:
  Fix for CVE-2017-10791 included in PSPP 0.11.0 version upstream.
* Sat Jul 29 2017 opensuse.lietuviu.kalba@gmail.com
- Add pspp-0001-sys-file-reader-Avoid-null-dereference-skipping-bad-.patch
  to fix NULL Pointer dereference in ll_insert (bnc#1046997, CVE-2017-10792).
- Add pspp-0002-sys-file-reader-Fix-integer-overflows-in-parse_long_.patch
  to fix  Integer overflow in the hash_int library (bnc#1046998, CVE-2017-10791).
* Mon Feb  6 2017 dimstar@opensuse.org
- Port to ncurses6 (instead of using the deprecated mcurses5):
  + export NCURSES_CONFIG=%%{_bindir}/ncurses6-config if the binary
    exists. In case it does not, the default search algorithm of
    configure is being used, meaning ncurses5-config, followed by
    ncurses8-config.
* Wed Aug  3 2016 opensuse.lietuviu.kalba@gmail.com
- Update to 0.10.2:
  * CROSSTABS implements a new COUNT subcommand to round case or cell
  weights.
  * Help will be opened as HTML in default browser if yelp
  is not available.
  * When plotting scatterplots with only one dataset (the simple case)
  the colour used for the dataset is now black. The previous default
  from the Tango palette was too faint to see easily.
  * The varible info dialog could previously only paste a single variable.
  Now it can paste multiple variables.
  * Bug fixes, including the following:
  - T-test with independent samples GUI crashed with string
    type variable as group variable.
  - The variable info dialog showed the previous selected variable
    superimposed with the currently selected one.
  - The GLM command did not properly deal with missing values. This
    has been fixed.
* Sun Apr  3 2016 opensuse.lietuviu.kalba@gmail.com
- Update to 0.10:
  * The QUICK CLUSTER command has a  /PRINT subcommand which shows
  the initial cluster centres and the final cluster membership of
  each case.  The clustering algorithm has also been updated, so
  as to produce better separated clusters.
  * If the DECIMAL character is set to COMMA then the ',' character
  will not be treated as a separator by DATA LIST.
  * The graphical user interface (psppire) has been changed as follows:
  - It now uses Gtk+ version 3 instead of version 2.
  - There is now a Graphs menu to access the GRAPH command.
  - The status of dialog box widgets are now preserved between calls
    to the same dialog box for the same dataset.
  - The dialog box for the Logistic Regression command will now
    infer that string variables or any varible with a "measure"
    of Nominal or Ordinal are to be treated as categorical variables
    and will generate syntax accordingly.
  * The pspp-convert utility can now decrypt encrypted syntax files.
  The encrypted syntax file format is unacceptably insecure, so to
  discourage its use PSPP and PSPPIRE do not directly read or write
  this format.
  * New commands:
  - SORT VARIABLES.
  * The following functions for transformation expressions are new:
  - REPLACE, for search-and-replace of one string with another.
  - STRUNC, to truncate a string and trim trailing spaces.
  - MEDIAN, to compute the median of its arguments.
  - The TRUNC function in expressions now supports additional arguments
    for truncating to values other than integers and to indicate a level
    of rounding fuzz.  The default rounding fuzz may now be controlled
    and displayed with SET FUZZBITS and SHOW FUZZBITS, respectively.
  * Various bug fixes.
* Tue Aug 18 2015 opensuse.lietuviu.kalba@gmail.com
- Update to 0.8.5:
  * The FREQUENCIES and CROSSTABS commands can now generate barcharts.
  * The FACTOR command can now perform PROMAX rotations.
  * SPSS/PC+ system files are now supported on GET and other commands
    that read SPSS system files.  The pspp-convert program can now read
    SPSS/PC+ system files.  Writing the obsolete SPSS/PC+ system file
    format is not supported.
  * SYSFILE INFO can now read SPSS/PC+ system files and SPSS portable
    files.
  * FREQUENCIES: A bug was fixed where an assertion failure occured
    when an empty dataset was presented.
  * The GRAPH command is now available.  Initially it supports
    scatterplots and histograms.
  * The RND operator in expressions now supports additional operands
    for rounding to values other than integers and to indicate a level
    of rounding fuzz.  The default rounding fuzz may now be controlled
    and displayed with SET FUZZBITS and SHOW FUZZBITS, respectively.
* Mon Nov  3 2014 embar@super.lt
- Update to 0.8.4:
  * Bug fixes.
  * More detailed changelog can be found here:
    http://git.savannah.gnu.org/cgit/pspp.git/tree/NEWS
* Sat Apr 26 2014 embar@super.lt
- Update to 0.8.3:
  * Independent T-Tests displayed the standard error of the difference
  and the confidence interval for the unequal variances case, where
  the equal variances case should have been.  This has been fixed.
  * REGRESSION now recognises /STATISTICS=CI(x) which causes confidence
  intervals for the coefficients to be printed.
  * When DESCRIPTIVES calculates Z scores, it now omits cases filtered
  by the current FILTER settings.
  * PSPPIRE graphical user interface improvements.
  * System file related improvements.
* Thu Apr 10 2014 embar@super.lt
- Update to 0.8.2.1. Detailed changelog can be found here:
  http://git.savannah.gnu.org/cgit/pspp.git/tree/NEWS
* Sun Jan 26 2014 embar@super.lt
- Update to 0.8.2. Detailed changelog can be found here:
  http://git.savannah.gnu.org/cgit/pspp.git/tree/NEWS
* Thu Aug  1 2013 embar@super.lt
- Update to 0.8.0. Detailed changelog can be found here:
  http://git.savannah.gnu.org/cgit/pspp.git/tree/NEWS
* Tue May  7 2013 embar@super.lt
- merged 'psppsheet' branch
* Wed Mar 27 2013 embar@super.lt
- Update to 0.7.10
* Tue Jan 10 2012 embar@super.lt
- Update to 0.7.8-gbc9098
- Fix compiling for openSUSE 12.1
* Fri Aug 20 2010 embar@super.lt
- Update to 0.7.5-g7803d3
* Fri Nov 14 2008 Detlef Steuer <steuer@hsuhh.de> - 0.6.1-0
- First try for the Opensuse Buildservice
* Thu Sep 25 2008 Matj Cepl <mcepl@redhat.com> - 0.6.0-8
- Fix wrong CFLAGS -- add -fgnu89-inline
* Mon Jul  7 2008 Matej Cepl <mcepl@redhat.com> 0.6.0-7
- Fix BuildRequires.
* Wed Jun 18 2008 Matej Cepl <mcepl@redhat.com> 0.6.0-6
- Bug 451006 has been resolved, so we don't have to munge CFLAGS
  anymore.
* Sat Jun 14 2008 Matj Cepl <mcepl@redhat.com> 0.6.0-5
- Approved version with fixed duplicate %%%%{_sysconfdir}/pspp
* Fri Jun 13 2008 Matj Cepl <mcepl@redhat.com> 0.6.0-4
- Second wave of Package Review -- .desktop file
- Mysterious libraries eliminated
* Thu Jun 12 2008 Matj Cepl <mcepl@redhat.com> 0.6.0-3
- First wave of Package Review nitpicking -- added %%%%doc and fixed Texinfo
  handling.
* Thu Jun 12 2008 Matj Cepl <mcepl@redhat.com> 0.6.0-2
- Upstream release, this build is to be put into the package review.
* Tue Apr 22 2008 Matj Cepl <mcepl@redhat.com> 0.6.0-0.1.pre2
- Upstream pre-release.
* Mon Apr 23 2007 Matej Cepl <mcepl@redhat.com> - 0.4.0-1
- The first experimental package of PSPP for Fedora.
